@@ -1,4 +1,4 @@
-/* $Id: hawki_step_photom_2mass.c,v 1.18 2013/01/14 15:58:23 cgarcia Exp $
+/* $Id: hawki_step_photom_2mass.c,v 1.20 2013-09-02 14:22:38 cgarcia Exp $
  *
  * This file is part of the HAWKI Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
@@ -15,14 +15,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 /*
  * $Author: cgarcia $
- * $Date: 2013/01/14 15:58:23 $
- * $Revision: 1.18 $
- * $Name: hawki-1_8_12 $
+ * $Date: 2013-09-02 14:22:38 $
+ * $Revision: 1.20 $
+ * $Name: not supported by cvs2svn $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -340,11 +340,11 @@ cpl_table ** hawki_step_photom_2mass_get_zpoints
     zpoint_table = cpl_malloc(sizeof(cpl_table *) * HAWKI_NB_DETECTORS);
 
     /* Load detected obj */
-    obj_det_param = hawki_load_tables(cpl_frameset_get_first(obj_param));
+    obj_det_param = hawki_load_tables(cpl_frameset_get_position(obj_param, 0));
      
     /* Read the main header */
     plist = cpl_propertylist_load
-        (cpl_frame_get_filename(cpl_frameset_get_first(obj_ima)), 0);
+        (cpl_frame_get_filename(cpl_frameset_get_position(obj_ima, 0)), 0);
     /* Loop on detectors */    
     for(idet = 0; idet < HAWKI_NB_DETECTORS; ++idet)
     {
@@ -358,9 +358,9 @@ cpl_table ** hawki_step_photom_2mass_get_zpoints
          
         /* Retrieve stars */
         ext_nb=hawki_get_ext_from_detector
-            (cpl_frame_get_filename(cpl_frameset_get_first(obj_ima)),idet+1);
+            (cpl_frame_get_filename(cpl_frameset_get_position(obj_ima, 0)),idet+1);
         wcs_info = cpl_propertylist_load
-            (cpl_frame_get_filename(cpl_frameset_get_first(obj_ima)), ext_nb);
+            (cpl_frame_get_filename(cpl_frameset_get_position(obj_ima, 0)), ext_nb);
         stars_2mass = 
             hawki_step_photom_2mass_retrieve_stars(cat_2mass, wcs_info);        
         if(stars_2mass == NULL)
@@ -446,7 +446,7 @@ static cpl_table *  hawki_step_photom_2mass_retrieve_stars
     
 
     /* Extract the catalog path */
-    if (irplib_2mass_get_catpars(cpl_frameset_get_first(cat_2mass),
+    if (irplib_2mass_get_catpars(cpl_frameset_get_position(cat_2mass, 0),
                                  &catpath, &catname) != CPL_ERROR_NONE) 
         return NULL;
     
@@ -952,7 +952,7 @@ static int hawki_step_photom_2mass_save
 
     /* Get the reference frame */
     combinedframes = hawki_extract_frameset(set, HAWKI_CALPRO_COMBINED);
-    ref_frame = cpl_frameset_get_first(combinedframes);
+    ref_frame = cpl_frameset_get_position(combinedframes, 0);
 
     /* Create the protype lists */
     protype = cpl_propertylist_new();
